@@ -5,6 +5,7 @@ import configparser
 
 from pathlib import Path
 from tqdm import tqdm
+from numba import njit
 from typing import cast
 from collections import Counter
 from scipy.stats import multivariate_normal as mn
@@ -16,6 +17,12 @@ from figaro.exceptions import FIGAROException
 # Utilities #
 #-----------#
 
+@njit
+def _rescale_matrix(S, n):
+    std = np.sqrt(np.diag(S))
+    rho = np.divide(S, np.outer(std,std))
+    return rho * np.outer(std/np.sqrt(n), std/np.sqrt(n))
+
 def recursive_grid(bounds, n_pts, get_1d = False):
     """
     Recursively generates the n-dimensional grid points (extremes are excluded).
@@ -155,35 +162,11 @@ def get_priors(bounds, samples = None, mean = None, std = None, cov = None, df =
             df_out = dim+2
             
         draw_flag = False
-        # Mu
-        if mean is not None:
-            mean = np.atleast_1d(mean)
-            if not np.prod(bounds[:,0] < mean) & np.prod(mean < bounds[:,1]):
-                raise ValueError("Mean is outside of the given bounds")
-            if probit:
-                mu_out = transform_to_probit(mean, bounds)
-            else:
-                mu_out = mean
-        elif samples is not None:
-            if probit:
-                mu_out = np.atleast_1d(np.median(probit_samples, axis = 0))
-            else:
-                mu_out = np.atleast_1d(np.median(samples, axis = 0))
-        else:
-            if probit:
-                mu_out = np.zeros(dim)
-            else:
-                mu_out = np.atleast_1d(np.mean(bounds, axis = 1))
         # L
         if cov is not None:
             L_out = cov
-            if probit:
-                draw_flag = True
         elif std is not None:
-            if probit:
-                L_out = np.identity(dim)*np.minimum(np.abs(mu_out - transform_to_probit((transform_from_probit(mu_out, bounds) + std), bounds)), np.abs(mu_out - transform_to_probit((transform_from_probit(mu_out, bounds) - std), bounds)))**2
-            else:
-                L_out = np.identity(dim)*std**2
+            L_out = np.identity(dim)*std**2
         elif samples is not None:
             if probit:
                 cov_samples = np.atleast_2d(np.cov(probit_samples.T))
@@ -196,27 +179,7 @@ def get_priors(bounds, samples = None, mean = None, std = None, cov = None, df =
                 L_out = np.identity(dim)*sigma**2
             else:
                 L_out = np.identity(dim)*(np.diff(bounds, axis = -1).flatten()/scale)**2
-        if draw_flag:
-            ss = mn(np.mean(bounds, axis = -1), L_out, allow_singular = True).rvs(3000)
-            if dim == 1:
-                ss = np.atleast_2d(ss).T
-            # Keeping only samples within bounds
-            ss = ss[np.where((np.prod(bounds[:,0] < ss, axis = 1) & np.prod(ss < bounds[:,1], axis = 1)))]
-            probit_ss = transform_to_probit(ss, bounds)
-            L_out = np.identity(dim)*np.diag(np.atleast_2d(np.cov(probit_ss.T)))
-        # k
-        if k is not None:
-            k_out = k
-        else:
-            if samples is not None:
-                if probit:
-                    cov_samples = np.atleast_2d(np.cov(probit_samples.T))
-                else:
-                    cov_samples = np.atleast_2d(np.cov(samples.T))
-                k_out = np.min(np.diag(L_out)/np.diag(cov_samples))
-            else:
-                k_out = 1./(scale)
-        return (k_out, L_out, df_out, mu_out)
+        return (L_out, df_out)
 
 def rvs_median(draws, size = 1):
     """
